==> magpie-data-0.6.1-sources.jar: io/openraven/magpie/data/aws/accounts/IamRole.java <==
/*-
 * #%L
 * Magpie API
 * %%
 * Copyright (C) 2021 Open Raven Inc
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
/*
 * Copyright 2021 Open Raven Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.openraven.magpie.data.aws.accounts;

import io.openraven.magpie.data.aws.AWSResource;
import io.openraven.magpie.data.aws.shared.PayloadUtils;
import software.amazon.awssdk.services.iam.model.Role;

@javax.persistence.Entity
@javax.persistence.Inheritance(strategy = javax.persistence.InheritanceType.TABLE_PER_CLASS)
@javax.persistence.Table(name = IamRole.TABLE_NAME)
public class IamRole extends AWSResource {
  protected static final String TABLE_NAME = "awsiamrole";
  public static final String RESOURCE_TYPE = "AWS::IAM::Role";

  public IamRole() {
    this.resourceType = RESOURCE_TYPE;

  }

  public IamRole(String accountId, String region, Role role) {
    this.arn = role.arn();
    this.awsAccountId = accountId;
    this.awsRegion = region;
    this.resourceId = role.roleId();
    this.resourceName = role.roleName();
    this.resourceType = RESOURCE_TYPE;
    this.createdIso = role.createDate();
    this.configuration = PayloadUtils.update(role);
  }
}

==> magpie-data-0.11.6-sources.jar: io/openraven/magpie/data/aws/accounts/IamRole.java <==
/*-
 * #%L
 * Magpie API
 * %%
 * Copyright (C) 2021 Open Raven Inc
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
/*
 * Copyright 2021 Open Raven Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.openraven.magpie.data.aws.accounts;

import io.openraven.magpie.data.aws.AWSResource;
import io.openraven.magpie.data.aws.shared.PayloadUtils;
import software.amazon.awssdk.services.iam.model.Role;

@jakarta.persistence.Entity
@jakarta.persistence.Inheritance(strategy = jakarta.persistence.InheritanceType.TABLE_PER_CLASS)
@jakarta.persistence.Table(name = IamRole.TABLE_NAME)
public class IamRole extends AWSResource {
  protected static final String TABLE_NAME = "awsiamrole";
  public static final String RESOURCE_TYPE = "AWS::IAM::Role";

  public IamRole() {
    this.resourceType = RESOURCE_TYPE;

  }

  public IamRole(String accountId, String region, Role role) {
    this.arn = role.arn();
    this.awsAccountId = accountId;
    this.awsRegion = region;
    this.resourceId = role.roleId();
    this.resourceName = role.roleName();
    this.resourceType = RESOURCE_TYPE;
    this.createdIso = role.createDate();
    this.configuration = PayloadUtils.update(role);
  }
}
